==> kubernetes-model-core-5.12.2-sources.jar: io/fabric8/kubernetes/api/model/UpdateOptionsBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class UpdateOptionsBuilder extends io.fabric8.kubernetes.api.model.UpdateOptionsFluentImpl<io.fabric8.kubernetes.api.model.UpdateOptionsBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.UpdateOptions,io.fabric8.kubernetes.api.model.UpdateOptionsBuilder>{
  public UpdateOptionsBuilder() {
    this(false);
  }
  public UpdateOptionsBuilder(java.lang.Boolean validationEnabled) {
    this(new UpdateOptions(), validationEnabled);
  }
  public UpdateOptionsBuilder(io.fabric8.kubernetes.api.model.UpdateOptionsFluent<?> fluent) {
    this(fluent, false);
  }
  public UpdateOptionsBuilder(io.fabric8.kubernetes.api.model.UpdateOptionsFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new UpdateOptions(), validationEnabled);
  }
  public UpdateOptionsBuilder(io.fabric8.kubernetes.api.model.UpdateOptionsFluent<?> fluent,io.fabric8.kubernetes.api.model.UpdateOptions instance) {
    this(fluent, instance, false);
  }
  public UpdateOptionsBuilder(io.fabric8.kubernetes.api.model.UpdateOptionsFluent<?> fluent,io.fabric8.kubernetes.api.model.UpdateOptions instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withDryRun(instance.getDryRun()); 
    fluent.withFieldManager(instance.getFieldManager()); 
    fluent.withFieldValidation(instance.getFieldValidation()); 
    fluent.withKind(instance.getKind()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public UpdateOptionsBuilder(io.fabric8.kubernetes.api.model.UpdateOptions instance) {
    this(instance,false);
  }
  public UpdateOptionsBuilder(io.fabric8.kubernetes.api.model.UpdateOptions instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withDryRun(instance.getDryRun()); 
    this.withFieldManager(instance.getFieldManager()); 
    this.withFieldValidation(instance.getFieldValidation()); 
    this.withKind(instance.getKind()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.UpdateOptionsFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.UpdateOptions build() {
    UpdateOptions buildable = new UpdateOptions(fluent.getApiVersion(),fluent.getDryRun(),fluent.getFieldManager(),fluent.getFieldValidation(),fluent.getKind());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    UpdateOptionsBuilder that = (UpdateOptionsBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-core-6.3.1-sources.jar: io/fabric8/kubernetes/api/model/UpdateOptionsBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class UpdateOptionsBuilder extends UpdateOptionsFluentImpl<UpdateOptionsBuilder> implements VisitableBuilder<UpdateOptions,UpdateOptionsBuilder>{
  public UpdateOptionsBuilder() {
    this(false);
  }
  public UpdateOptionsBuilder(Boolean validationEnabled) {
    this(new UpdateOptions(), validationEnabled);
  }
  public UpdateOptionsBuilder(UpdateOptionsFluent<?> fluent) {
    this(fluent, false);
  }
  public UpdateOptionsBuilder(UpdateOptionsFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new UpdateOptions(), validationEnabled);
  }
  public UpdateOptionsBuilder(UpdateOptionsFluent<?> fluent,UpdateOptions instance) {
    this(fluent, instance, false);
  }
  public UpdateOptionsBuilder(UpdateOptionsFluent<?> fluent,UpdateOptions instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withDryRun(instance.getDryRun()); 
    fluent.withFieldManager(instance.getFieldManager()); 
    fluent.withFieldValidation(instance.getFieldValidation()); 
    fluent.withKind(instance.getKind()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public UpdateOptionsBuilder(UpdateOptions instance) {
    this(instance,false);
  }
  public UpdateOptionsBuilder(UpdateOptions instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withDryRun(instance.getDryRun()); 
    this.withFieldManager(instance.getFieldManager()); 
    this.withFieldValidation(instance.getFieldValidation()); 
    this.withKind(instance.getKind()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  UpdateOptionsFluent<?> fluent;
  Boolean validationEnabled;
  public UpdateOptions build() {
    UpdateOptions buildable = new UpdateOptions(fluent.getApiVersion(),fluent.getDryRun(),fluent.getFieldManager(),fluent.getFieldValidation(),fluent.getKind());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
